@@ -11,9 +11,9 @@ import urllib3
 from base64 import b64decode, b64encode
 from sleekxmppfs import ClientXMPP, Callback, MatchXPath
 from sleekxmppfs.exceptions import XMPPError
-from map import Map
-from constants import *
-from ecovacsiotmq import *
+from .map import *
+from .constants import *
+from .ecovacsiotmq import *
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -283,6 +283,7 @@ class VacBot():
         self.rooms = []
         self.last_clean_image = None
         self.Map = Map()
+        self.live_map = None
 
         #Set none for clients to start        
         self.iotmq = None
@@ -501,6 +502,8 @@ class VacBot():
         try:
             print("LIVE MAP START")
             self.exc_command('getMajorMap')
+            self.live_map = self.Map.GetBase64Map()
+
             print("LIVE MAP END")
         except XMPPError as err:
             _LOGGER.warning("Initial live map failed to reach VacBot. Will try again on next ping.")
